@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-package JSON::RPC::Common::Procedure::Return::Version_2_0::Error;
+package JSON::RPC::Common::Procedure::Return::Version_1_1::Error;
 use Moose;
 
 use JSON::RPC::Common::TypeConstraints qw(JSONValue);
@@ -14,17 +14,23 @@ has '+message' => (
 );
 
 has '+code' => (
-	required => 1,
+	default => 500,
+);
+
+has name => (
+	is      => "rw",
+	default => "JSONRPCError", # fucking idiots
 );
 
 sub deflate {
 	my $self = shift;
 
 	return {
-		code    => $self->code,
+		name    => $self->name,
 		message => $self->message,
-		( $self->has_data ? ( data => $self->data ) : () ),
-	};
+		code    => $self->code,
+		( $self->has_data ? ( error => $self->data ) : () ),
+	},
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -37,7 +43,7 @@ __END__
 
 =head1 NAME
 
-JSON::RPC::Common::Procedure::Return::Version_2_0::Error - JSON-RPC 2.0 error
+JSON::RPC::Common::Procedure::Return::Version_1_1::Error - JSON-RPC 1.1 error
 class.
 
 =head1 SYNOPSIS
@@ -46,10 +52,13 @@ class.
 
 =head1 DESCRIPTION
 
-This class implements 2.0 error objects.
+This class implements 1.1 error objects.
 
 C<code> and C<message> are mandatory.
 
+The C<data> field is named C<error> in the deflated version and C<name> is set
+to C<JSONRPCError>. How exciting.
+
 See L<JSON::RPC::Common::Procedure::Return::Error>.
 
 =cut
