@@ -6,12 +6,13 @@ use strict;
 use warnings;
 
 use MooseX::Types -declare => [qw(JSONDefined JSONValue JSONContainer)];
+use MooseX::Types::Moose qw(Value ArrayRef HashRef Undef);
 
-subtype JSONDefined, as "Value|ArrayRef|HashRef";
+subtype JSONDefined, as Value|ArrayRef|HashRef;
 
-subtype JSONValue, as 'Undef|Value|ArrayRef|HashRef';
+subtype JSONValue, as Undef|Value|ArrayRef|HashRef;
 
-subtype JSONContainer, as 'ArrayRef|HashRef';
+subtype JSONContainer, as ArrayRef|HashRef;
 
 __PACKAGE__
 
